ApiAccount class

Constructors

ApiAccount(PolkawalletApi apiRoot, ServiceAccount service)

Properties

apiRoot → PolkawalletApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceAccount
final

Methods

checkAddressFormat(String address, int ss58) → Future<bool?>
check address matches ss58Format
decodeAddress(List<String> addresses) → Future<Map?>
decode addresses to publicKeys
encodeAddress(List<String> pubKeys) → Future<Map?>
encode addresses to publicKeys
getAddressIcons(List addresses) → Future<List?>
Get icons of addresses return svg strings
getPubKeyIcons(List<String> keys) → Future<List?>
Get icons of pubKeys return svg strings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAddressWithAccountIndex(String index) → Future<String?>
query address with account index
queryBalance(String? address) → Future<BalanceData?>
query balance
queryIndexInfo(List addresses) → Future<List?>
Get on-chain account info of addresses
subscribeBalance(String? address, dynamic onUpdate(BalanceData)) → Future<String>
subscribe balance @return String msgChannel, call unsubscribeMessage(msgChannel) to unsub.
toString() → String
A string representation of this object.
inherited
unsubscribeBalance() → void
unsubscribe balance

Operators

operator ==(Object other) → bool
The equality operator.
inherited