ApiAssets class

Constructors

ApiAssets(PolkawalletApi apiRoot, ServiceAssets service)

Properties

apiRoot → PolkawalletApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceAssets
final

Methods

getAssetsAll() → Future<List<TokenBalanceData>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAssetsBalances(List<String> ids, String address) → Future<List<AssetsBalanceData>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited