ApiBridge class

Constructors

ApiBridge(PolkawalletApi apiRoot, ServiceBridge service)

Properties

apiRoot → PolkawalletApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceBridge
final

Methods

addMsgHandler(String channel, Function onMessage) → void
checkAddressFormat(String address, int ss58) → Future<bool>
checkPassword(Map keyring, KeyPairData account, String pass) → Future<bool>
connectFromChains(List<String> chains, {Map<String, List<String>>? nodeList}) → Future<List<String>>
disconnectFromChains() → Future<void>
dispose() → Future<void>
estimateTxFee(String chainFrom, String txHex, String sender) → Future<String>
getAcalaEVMTokens() → Future<List<String>>
getAmountInputConfig(String from, String to, String token, String address, String signer) → Future<BridgeAmountInputConfig>
getChainsInfo() → Future<Map<String, BridgeChainData>>
getEvalJavascriptUID() → int
getFromChainsAll() → Future<List<String>>
getNetworkProperties(String chain) → Future<BridgeNetworkProperties>
getRoutes() → Future<List<BridgeRouteData>>
getTxParams(String from, String to, String token, String address, String amount, int decimals, String signer) → Future<BridgeTxParams>
init({String? jsCode}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → Future<void>
removeMsgHandler(String channel) → void
sendTx(String chainFrom, Map txInfo, String password, String msgId, Map keyring) → Future<Map?>
subscribeBalances(String chain, String address, dynamic callback(Map<String, BridgeTokenBalance>)) → Future<void>
subscribeReloadAction(String reloadKey, Function reloadAction) → void
toString() → String
A string representation of this object.
inherited
unsubscribeBalances(String chain, String address) → Future<void>
unsubscribeReloadAction(String reloadKey) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited