ApiRecovery class

Constructors

ApiRecovery(PolkawalletApi apiRoot, ServiceRecovery service)

Properties

apiRoot → PolkawalletApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceRecovery
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryActiveRecoveries(List<String> addresses, String addressNew) → Future<List?>
queryActiveRecoveryAttempts(String address, List<String> addressNew) → Future<List?>
queryRecoverable(String address) → Future<RecoveryInfo?>
queryRecoverableList(List<String> addresses) → Future<List<RecoveryInfo>>
queryRecoveryProxies(List<String> addresses) → Future<List?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited