ApiSetting class

Constructors

ApiSetting(PolkawalletApi apiRoot, ServiceSetting? service)

Properties

apiRoot → PolkawalletApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceSetting?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryNetworkConst() → Future<Map?>
query network const.
queryNetworkProps() → Future<NetworkStateData?>
query network properties.
subscribeBestNumber(Function callback) → Future<void>
subscribe best number. @return String msgChannel, call unsubscribeMessage(msgChannel) to unsub.
toString() → String
A string representation of this object.
inherited
unsubscribeBestNumber() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited