ApiStaking class

Constructors

ApiStaking(PolkawalletApi apiRoot, ServiceStaking service)

Properties

apiRoot → PolkawalletApi
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ServiceStaking
final

Methods

getAccountRewardsEraOptions() → Future<List?>
getSlashingSpans(String stashId) → Future<int?>
loadValidatorRewardsData(String validatorId) → Future<Map?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAccountRewards(String address, int eras) → Future<Map?>
queryBonded(List<String> pubKeys) → Future<Map<String?, AccountBondedInfo>>
query staking stash-controller relationship of a list of pubKeys, return list of pubKey, controllerAddress, stashAddress.
queryElectedInfo() → Future<Map?>
queryNominations() → Future<Map?>
queryNominationsCount() → Future<Map?>
queryOwnStashInfo(String accountId) → Future<OwnStashInfoData>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited