SubScanApi class

Querying txs from subscan.io.

Constructors

SubScanApi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
moduleBalances → String
final
moduleDemocracy → String
final
moduleRecovery → String
final
moduleStaking → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchRewardTxsAsync({int page = 0, int size = tx_list_page_size, String? sender, String network = 'kusama'}) → Future<Map>
fetchTransfersAsync(String address, int page, {int size = tx_list_page_size, String network = 'kusama'}) → Future<Map>
do the request in an isolate to avoid UI stall in IOS due to https issue: https://github.com/dart-lang/sdk/issues/41519
fetchTxsAsync(String module, {String? call, int page = 0, int size = tx_list_page_size, String? sender, String network = 'kusama'}) → Future<Map>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited