SubScanRequestParams class

Constructors

SubScanRequestParams({SendPort? sendPort, String? network, String? address, int? page, int? row, String? module, String? call})

Properties

address ↔ String?
getter/setter pair
call ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
module ↔ String?
getter/setter pair
network ↔ String?
getter/setter pair
page ↔ int?
getter/setter pair
row ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPort ↔ SendPort?
exec in isolate with a message send port
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited