TxData class

Annotations
  • @JsonSerializable.new()

Constructors

TxData()

Properties

accountId ↔ String?
getter/setter pairinherited
blockNum ↔ int?
getter/setter pairinherited
blockTimestamp ↔ int?
getter/setter pairinherited
call ↔ String?
getter/setter pairinherited
fee ↔ String?
getter/setter pairinherited
hash ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
module ↔ String?
getter/setter pairinherited
nonce ↔ int?
getter/setter pairinherited
params ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool?
getter/setter pairinherited
txNumber ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → TxData