PluginBasicData class

Constructors

PluginBasicData({String? name, String? genesisHash, int? ss58, MaterialColor? primaryColor, Color? gradientColor, AssetImage? backgroundImage, Widget? icon, Widget? iconDisabled, int? jsCodeVersion, bool isTestNet = true, bool isXCMSupport = false, String? parachainId})

Properties

backgroundImage → AssetImage?
The image will be displayed in network-select page
final
genesisHash → String?
final
gradientColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
The icons will be displayed in network-select page in Polkawallet App.
final
iconDisabled → Widget?
final
isTestNet → bool
Your plugin is connected to a para-chain testNet by default.
final
isXCMSupport → bool
Whether this para-chain receives assets from relay-chain. should set parachainId if isXCMSupport enabled.
final
jsCodeVersion → int?
JavaScript code version of your plugin.
final
name → String?
final
parachainId → String?
final
primaryColor → MaterialColor?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ss58 → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited