BalancesStore class

Inheritance

Constructors

BalancesStore()

Properties

context → ReactiveContext
Override this method to use a custom context.
no setterinherited
extraTokens ↔ List<ExtraTokenData>?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isTokensFromCache ↔ bool
getter/setter pairinherited
native ↔ BalanceData?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokens ↔ List<TokenBalanceData>
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBalance(BalanceData data) → void
inherited
setExtraTokens(List<ExtraTokenData> ls) → void
inherited
setTokens(List<TokenBalanceData> ls, {bool isFromCache = false}) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited