BalancesStoreBase class abstract

Implementers

Constructors

BalancesStoreBase()

Properties

context → ReactiveContext
Override this method to use a custom context.
no setterinherited
extraTokens ↔ List<ExtraTokenData>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isTokensFromCache ↔ bool
getter/setter pair
native ↔ BalanceData?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokens ↔ List<TokenBalanceData>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBalance(BalanceData data) → void
setExtraTokens(List<ExtraTokenData> ls) → void
setTokens(List<TokenBalanceData> ls, {bool isFromCache = false}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited