TokenBalanceData class

none-native token data

  1. id foreign asset id (Acala tokens module).
  2. name
  3. symbol
  4. fullName
  5. type <Token | DexShare | ForeignAsset> for Karura tokens.
  6. tokenNameId acala.js formatted tokenNameId, fa://0 for {ForeignAsset: 0}.
  7. currencyId acala currencyId type, {ForeignAsset: 0} for fa://0.

Constructors

TokenBalanceData({String? id, String? name, String? tokenNameId, String? symbol, String type = 'Token', Map? currencyId, Map? src, String? minBalance, String? fullName, int? decimals, String? amount, String? locked, String? reserved, String? detailPageRoute, double? price, double? getPrice()?, String priceCurrency = 'USD', double priceRate = 1.0})

Properties

amount ↔ String?
getter/setter pair
currencyId → Map?
final
decimals → int?
final
detailPageRoute ↔ String?
getter/setter pair
fullName → String?
final
getPrice ↔ double? Function()?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
locked → String?
final
minBalance → String?
final
name → String?
final
price → double?
final
priceCurrency ↔ String
getter/setter pair
priceRate ↔ double
getter/setter pair
reserved → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → Map?
final
symbol → String?
final
tokenNameId → String?
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited