ServiceSetting class

Constructors

ServiceSetting(SubstrateService serviceRoot)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceRoot → SubstrateService
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryNetwork() → Future<Map?>
queryNetworkConst() → Future<Map>
queryNetworkProps() → Future<Map?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited