LocalStorage class

Constructors

LocalStorage()

Properties

accountsKey → String
final
contactsKey → String
final
currentAccountKey → String
final
customKVKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seedKey → String
final
storage → _LocalStorage
final

Methods

addAccount(Map<String, dynamic> acc) → Future<void>
addContact(Map<String, dynamic> con) → Future<void>
getAccountCache(String accPubKey, String key) → Future<Object?>
getAccountList() → Future<List<Map<String, dynamic>>>
getContactList() → Future<List<Map<String, dynamic>>>
getCurrentAccount() → Future<String?>
getObject(String key) → Future<Object?>
getSeeds(String? seedType) → Future<Map>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAccount(String? pubKey) → Future<void>
removeContact(String address) → Future<void>
setAccountCache(String accPubKey, String key, Object value) → Future<void>
setCurrentAccount(String pubKey) → Future<bool>
setObject(String key, Object value) → Future<bool>
setSeeds(String seedType, Map value) → Future<bool>
toString() → String
A string representation of this object.
inherited
updateContact(Map<String, dynamic> con) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkCacheTimeout(int cacheTime) → bool

Constants

customCacheTimeLength → const int