WebViewEthInjected class

Inheritance

Constructors

WebViewEthInjected(PolkawalletApi api, String initialUrl, KeyringEVM keyringEVM, {required Keyring keyring, required Future<bool> onSwitchEvmChain(String), required Future<Map> onEvmRpcCall(Map), required Future<void> onAccountEmpty(String), dynamic onPageFinished(String)?, Function? onExtensionReady, dynamic onWebViewCreated(WebViewController)?, Future<WCCallRequestResult?> onSignRequestEVM(Map)?, Future<ExtensionSignResult?> onSignRequest(SignAsExtensionParam)?, Future<List<KeyPairData>> onConnectRequest(DAppConnectParam, {bool isEvm})?, List<KeyPairData> checkAuth(String, {bool isEvm})?})

Properties

api → PolkawalletApi
final
checkAuth → List<KeyPairData> Function(String, {bool isEvm})?
final
hashCode → int
The hash code for this object.
no setterinherited
initialUrl → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyring → Keyring
final
keyringEVM → KeyringEVM
final
onAccountEmpty → Future<void> Function(String)
final
onConnectRequest → Future<List<KeyPairData>> Function(DAppConnectParam, {bool isEvm})?
final
onEvmRpcCall → Future<Map> Function(Map)
final
onExtensionReady → Function?
final
onPageFinished → dynamic Function(String)?
final
onSignRequest → Future<ExtensionSignResult?> Function(SignAsExtensionParam)?
onSignBytesRequest & onSignExtrinsicRequest handles Substrate requests
final
onSignRequestEVM → Future<WCCallRequestResult?> Function(Map)?
onSignRequestEVM handles EVM requests
final
onSwitchEvmChain → Future<bool> Function(String)
final
onWebViewCreated → dynamic Function(WebViewController)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _WebViewEthInjectedState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited